<?php

App::uses('BuzzConditionsAppModel', 'BuzzConditions.Model');

class Condition extends BuzzConditionsAppModel {

/**
 * Behaviors
 *
 * @var array
 */
	public $actsAs = array(
		'BuzzTranslate.Translatable'
	);

	public $validate = array(
		'name' => array(
			'required' => array(
				'rule' => 'notEmpty',
				'message' => 'Required'
			),
			'max' => array(
				'rule' => array('maxLength', 45),
				'message' => 'No more than 45 characters'
			)
		),
		'content' => array(
			'required' => array(
				'rule' => 'notEmpty',
				'message' => 'Required'
			)
		),
	);

/**
 * After find logic
 *
 * @param array $results
 * @param bool $primary
 * @return array
 */
	public function afterFind($results, $primary = false) {
		$results = parent::afterFind($results, $primary);

		foreach ($results as &$result) {
			if (!empty($result[$this->alias]['content'])) {
				$result[$this->alias]['rendered_content'] = preg_replace_callback(
					'/\[(.*?)\]\((.*?)\)/',
					function ($matches) {
						return '<a href="' . $matches[2] . '" target="_blank">' . $matches[1] . '</a>';
					},
					htmlspecialchars($result[$this->alias]['content'])
				);
			}
		}

		return $results;
	}

/**
 * Returns all visible conditions for the given model
 *
 * @param string $model
 * @return array
 */
	public function getConditions($model) {
		$params = array(
			'conditions' => array(
				'Condition.model' => $model,
				'Condition.is_active' => true
			),
			'order' => array(
				'Condition.sequence' => 'ASC'
			)
		);
		return $this->find('all', $params);
	}

}
